@@ -2,5 +2,5 @@ from .video_indexer import LectureVideoIndexer
 from .Types import Config, Stage
 from .video_converter import VideoConverter, CropRegion
 
-__name__ = 'strsimpy'
-__version__ = "0.1.0"
+__name__ = 'lecture_video_indexer'
+__version__ = "0.1.1"
