@@ -7,5 +7,5 @@ from ..Types import VideoIndexEntry
 class FrameProcessor(ABC):
 
     @abstractmethod
-    def process_frame(self, frame: int, title: str) -> Optional[VideoIndexEntry]:
+    def process_frame(self, frame: int, title: str, text: str) -> Optional[VideoIndexEntry]:
         pass
